@@ -3,9 +3,10 @@ use ExtUtils::MakeMaker;
 
 WriteMakefile(
   NAME             => 'AsposeSlidesCloud::SlidesApi',
-  VERSION_FROM     => 'lib/AsposeSlidesCloud/ApiInfo.pm',
+  VERSION          => 19.12,
   ABSTRACT         => 'Aspose.Slides Cloud SDK',
   AUTHOR           => 'Victor Putrov',
   LICENSE          => 'MIT',
-  MIN_PERL_VERSION => '5.008004'
+  MIN_PERL_VERSION => '5.008004',
+  EXE_FILES        => ['lib/AsposeSlidesCloud']
 );
\ No newline at end of file
